Sijax - a Python/jQuery ajax library
####################################

Sijax stands for "Simple ajax" and provides just that.
It's a simple Python/jQuery library providing easy ajax integration for python web apps.

The main idea is to use javascript code that calls server-side callbacks, which generate a response (manipulating the DOM, etc) and pass it back to the client.
This way, you don't need to manually dispatch ajax requests to certain URIs and go over each XML/JSON response manually.

Sijax was initially developed for PHP, inspired by the Xajax_ library (PHP-only).

Take a look at the documentation_ to learn more.

.. _Xajax: http://xajax-project.org/
.. _documentation: http://packages.python.org/Sijax
